@@ -1,9 +1,11 @@
+from contextlib import suppress
 from pathlib import Path
+from typing import List, Union, cast
+
 import pandas as pd
-from typing import Union, List, cast
 
-from .csv_check import CSVCheck
 from ..result import DataCheckResult, ResultType
+from .csv_check import CSVCheck
 
 
 class ExcelCheck(CSVCheck):
@@ -19,12 +21,10 @@ class ExcelCheck(CSVCheck):
 
     def clean_excel_df(self, df: pd.DataFrame) -> pd.DataFrame:
         for column_name, column in df.items():
-            try:
+            with suppress(Exception):
                 if column.dtype == "object":
                     _col = column.apply(self.clean_string_column)
                     df[column_name] = _col
-            except Exception:
-                pass
         return df
 
     def read_expect_file(
