@@ -1,12 +1,15 @@
+from contextlib import suppress
 from pathlib import Path
-from typing import Union, List, cast, Tuple
+from typing import List, Tuple, Union, cast
+
+import numpy as np
 import pandas as pd
-import numpy as np
 
-from .base_check import BaseCheck
 from data_check.sql.query_result import QueryResult
-from ..result import DataCheckResult, ResultType
+
 from ..io import read_sql_file
+from ..result import DataCheckResult, ResultType
+from .base_check import BaseCheck
 
 
 class SQLBaseCheck(BaseCheck):
@@ -82,14 +85,10 @@ class SQLBaseCheck(BaseCheck):
         # float64 can be in scientific notation, so it cannot be compared against a str
         if col_1.dtype == np.float64 or col_2.dtype == np.float64:
             # use Float64 instead of np.float64 since it is nullable
-            try:
+            with suppress(Exception):
                 col_1 = col_1.astype("Float64")
-            except:
-                pass
-            try:
+            with suppress(Exception):
                 col_2 = col_2.astype("Float64")
-            except:
-                pass
         else:
             col_1 = col_1.astype("str")
             col_2 = col_2.astype("str")
