@@ -1,10 +1,10 @@
-import click
 from pathlib import Path
-from typing import Union, Optional
+from typing import Optional, Union
+
+import click
 
 from data_check.config import DataCheckConfig
 
-
 from .common import common_options, get_data_check
 
 
@@ -31,7 +31,7 @@ def fake(
     force: bool = False,
     configs: str = "",
 ):
-    """Run SQL statements."""
+    """Generate test data."""
     dc = get_data_check(
         ctx=ctx,
         connection=connection,
