@@ -1,11 +1,10 @@
-import click
 from pathlib import Path
-from typing import Union, List, Optional
+from typing import List, Optional, Union
+
+import click
 
-from data_check.data_check import DataCheck
 from data_check.config import DataCheckConfig
 
-
 from .common import common_options, get_data_check
 
 
