@@ -1,7 +1,12 @@
-from pathlib import Path
-from .io import read_yaml
-from typing import Optional, Dict, Any, Tuple
+from __future__ import annotations
 
+from pathlib import Path
+from typing import TYPE_CHECKING, Any, Dict, Optional, Tuple
+
+if TYPE_CHECKING:
+    from data_check.sql.load_mode import LoadMode
+
+from .io import read_yaml
 
 TEMPLATE_FILE = "template.yml"
 CHECKS_PATH = "checks"
@@ -46,8 +51,7 @@ class DataCheckConfig:
         """
         if self.project_path == self.base_path:
             return self.project_path / CHECKS_PATH
-        else:
-            return self.base_path
+        return self.base_path
 
     @property
     def template_path(self) -> Path:
@@ -101,3 +105,9 @@ class DataCheckConfig:
                 connection = default_connection
 
         return self.config.get("connections", {}).get(connection, ""), connection
+
+    @property
+    def default_load_mode(self) -> LoadMode:
+        from data_check.sql.load_mode import LoadMode
+
+        return LoadMode.from_string(self.config.get("default_load_mode", "truncate"))
