@@ -1,17 +1,17 @@
+import sys
+import traceback
 from pathlib import Path
+from typing import IO, Any, Callable, List, Optional, Tuple, Union, cast
+
 import pandas as pd
 from colorama import Fore, Style
-import traceback
-import sys
-from typing import IO, Callable, Optional, Any, Tuple, Union, List, cast
-
 
 from ..exceptions import DataCheckException
-from ..result import DataCheckResult, ResultType
 from ..io import rel_path
+from ..result import DataCheckResult, ResultType
+from .diffed_df import get_diffed_df
 from .handler import OutputHandler
 from .result_formatter import format_data_check_result
-from .diffed_df import get_diffed_df
 
 
 class DataCheckOutput:
@@ -66,10 +66,9 @@ class DataCheckOutput:
     def format_exception(exc: Exception):
         if sys.version_info >= (3, 10):
             return traceback.format_exception(exc)
-        else:
-            return traceback.format_exception(
-                value=exc, tb=exc.__traceback__, etype=Exception
-            )
+        return traceback.format_exception(
+            value=exc, tb=exc.__traceback__, etype=Exception
+        )
 
     def print_exception(self, exc: Exception):
         if self.traceback:
@@ -106,8 +105,7 @@ class DataCheckOutput:
                 return result.full_result
             elif isinstance(result.result, pd.DataFrame):
                 return result.result
-            else:
-                return pd.DataFrame()
+            return pd.DataFrame()
 
     def prepare_pprint_df(
         self, result: Union[DataCheckResult, pd.DataFrame]
