@@ -1,12 +1,11 @@
-from concurrent.futures import Executor, ProcessPoolExecutor, Future, as_completed
-from typing import Callable, List, Any, Dict, Optional, Tuple
 import multiprocessing as mp
 import sys
+from concurrent.futures import Executor, Future, ProcessPoolExecutor, as_completed
+from typing import Any, Callable, Dict, List, Optional, Tuple
 
 from .checks.base_check import BaseCheck
-from .result import DataCheckResult
 from .output import DataCheckOutput
-
+from .result import DataCheckResult
 
 if sys.version_info >= (3, 9):
     SubmitResult = Future[Any]
@@ -15,7 +14,7 @@ else:
 
 
 class NoPoolExecutor(Executor):
-    def submit(
+    def submit(  # type: ignore
         self, fn: Callable[..., Any], *args: Tuple[Any], **kwargs: Dict[str, Any]
     ) -> SubmitResult:
         f: SubmitResult = Future()
@@ -43,8 +42,7 @@ class DataCheckRunner:
         # if we can process the work in this process:
         if max_new_workers > 1:
             return ProcessPoolExecutor(max_workers=max_new_workers)
-        else:
-            return NoPoolExecutor()
+        return NoPoolExecutor()
 
     def run_checks(
         self,
