@@ -1,24 +1,27 @@
-from typing import Dict, Any, Optional, Union, List
+import warnings
+from functools import cached_property
 from os import path
-from sqlalchemy import create_engine, event
-from sqlalchemy.engine import Engine, Connection
-from sqlalchemy.engine.row import Row
+from pathlib import Path
+from typing import Any, Dict, List, Optional, Union, cast
+
+import pandas as pd
+from sqlalchemy import create_engine, event, inspect
+from sqlalchemy.engine import Connection, Engine
 from sqlalchemy.engine.cursor import CursorResult
+from sqlalchemy.engine.reflection import Inspector
+from sqlalchemy.engine.row import Row
 from sqlalchemy.sql import text
 from sqlalchemy.sql.elements import TextClause
 from sqlalchemy.sql.expression import bindparam
-import pandas as pd
-from pathlib import Path
-from functools import cached_property
 
+from data_check.config import DataCheckConfig
 
 from ..exceptions import DataCheckException
-from ..output import DataCheckOutput
 from ..io import print_csv, write_csv
+from ..output import DataCheckOutput
 from ..runner import DataCheckRunner
-from .table_loader import TableLoader
-from .table_info import TableInfo
 from .query_result import QueryResult
+from .table_loader import TableLoader
 
 
 class DataCheckSql:
@@ -27,6 +30,7 @@ class DataCheckSql:
         connection: str,
         runner: Optional[DataCheckRunner] = None,
         output: Optional[DataCheckOutput] = None,
+        config: Optional[DataCheckConfig] = None,
     ) -> None:
         self.connection = connection
         self.__connection: Optional[Connection] = None
@@ -40,16 +44,16 @@ class DataCheckSql:
             runner = DataCheckRunner(workers=1, output=self.output)
         self.runner = runner
 
+        if config is None:
+            config = DataCheckConfig()
+        self.config = config
+
     @cached_property
     def table_loader(self) -> TableLoader:
         """
         Lazy-load a TableLoader.
         """
-        return TableLoader(self, self.output)
-
-    @cached_property
-    def table_info(self) -> TableInfo:
-        return TableInfo(self)
+        return TableLoader(self, self.output, self.config.default_load_mode)
 
     def get_db_params(self) -> Dict[str, Any]:
         """
@@ -83,7 +87,7 @@ class DataCheckSql:
             # do not use CLOB for loading strings (and large decimals)
             # https://docs.sqlalchemy.org/en/14/dialects/oracle.html#example-2-remove-all-bindings-to-clob
             try:
-                from cx_Oracle import CLOB
+                from cx_Oracle import CLOB  # type: ignore
             except ImportError:
                 CLOB = None
 
@@ -131,8 +135,8 @@ class DataCheckSql:
 
     @staticmethod
     def _bindparams(query: str) -> TextClause:
-        sql = text(query)
-        for bp in sql._bindparams.keys():
+        sql = cast(TextClause, text(query))
+        for bp in sql._bindparams.keys():  # type: ignore
             sql = sql.bindparams(bindparam(bp, expanding=True))
         return sql
 
@@ -142,8 +146,9 @@ class DataCheckSql:
         if not self.connection:
             raise DataCheckException(f"undefined connection: {self.connection}")
         sql = self._bindparams(query)
-
-        result = QueryResult(query, self.get_connection().execute(sql, **params))
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore")  # ignore RemovedIn20Warning
+            result = QueryResult(query, self.get_connection().execute(sql, **params))
         return result
 
     def test_connection(self) -> bool:
@@ -174,7 +179,7 @@ class DataCheckSql:
         )
         try:
             res: List[Row] = result.fetchall()
-            columns: List[str] = result.keys()
+            columns: List[str] = list(result.keys())
             df = pd.DataFrame(data=res, columns=columns)
             if output:
                 write_csv(df, output=output, base_path=base_path)
@@ -183,3 +188,13 @@ class DataCheckSql:
             return res
         except Exception:
             return bool(result)
+
+    @property
+    def inspector(self) -> Inspector:
+        if self.keep_connection():
+            return self.cached_inspector
+        return cast(Inspector, inspect(self.get_engine()))
+
+    @cached_property
+    def cached_inspector(self) -> Inspector:
+        return cast(Inspector, inspect(self.get_engine()))
